@@ -1,11 +1,11 @@
-// Copyright (c) 2019 ETH Zurich, Mattia Gollub (mattia.gollub@bsse.ethz.ch)
+// Copyright (c) 2021 ETH Zurich, Mattia Gollub (mattia.gollub@bsse.ethz.ch)
 // Computational Systems Biology group, D-BSSE
 //
 // This software is freely available under the GNU General Public License v3.
 // See the LICENSE file or http://www.gnu.org/licenses/ for further information.
 
-#ifndef HYPERFLUX_MATLAB_PROGRESS_LOGGER_H
-#define HYPERFLUX_MATLAB_PROGRESS_LOGGER_H
+#ifndef PTA_MATLAB_PROGRESS_LOGGER_H
+#define PTA_MATLAB_PROGRESS_LOGGER_H
 
 #include <chrono>
 #include <iomanip>
@@ -14,7 +14,7 @@
 
 #include "progress_logger.h"
 
-namespace hyperflux {
+namespace pta {
 
 /**
  * @brief MCMC logger reporting the status on the simulation on the console.
@@ -24,7 +24,7 @@ namespace hyperflux {
  */
 template <typename ChainState, typename DurationFormat = std::chrono::milliseconds>
 class MatlabProgressLogger : public ProgressLogger<ChainState, DurationFormat> {
-public:
+  public:
     /**
      * @brief Construct a new ConsoleLogger object.
      *
@@ -36,17 +36,14 @@ public:
                          const std::chrono::milliseconds log_period_s)
         : ProgressLogger<ChainState, DurationFormat>(worker_id, log_period_s),
           matlab_engine_(matlab_engine)
-    {
-    }
+    {}
 
     MatlabProgressLogger(const MatlabProgressLogger<ChainState, DurationFormat>& other)
         : ProgressLogger<ChainState, DurationFormat>(other),
-          matlab_engine_(other.matlab_engine_),
-          factory_()
-    {
-    }
+          matlab_engine_(other.matlab_engine_), factory_()
+    {}
 
-protected:
+  protected:
     void print_progress(const std::string& progress_string) override
     {
         // Pass stream content to MATLAB fprintf function
@@ -56,12 +53,12 @@ protected:
             std::vector<matlab::data::Array>({factory_.createScalar(progress_string)}));
     }
 
-private:
+  private:
     std::shared_ptr<matlab::engine::MATLABEngine> matlab_engine_;
 
     matlab::data::ArrayFactory factory_;
 };
 
-}  // namespace hyperflux
+} // namespace pta
 
 #endif
\ No newline at end of file
