@@ -13,31 +13,49 @@ namespace samply {
 
 template <typename Scalar> struct AxisRaysPacket {
     Matrix<Scalar> origins;
-    IndexVector axis_ids;
+    IndexVector directions;
+
+    void at(Matrix<Scalar>& output_points, const Vector<Scalar>& t) const
+    {
+        output_points = origins;
+        for (Eigen::Index i = 0u; i < t.size(); ++i)
+            output_points(directions(i), i) += t(i);
+    }
 
     Matrix<Scalar> at(const Vector<Scalar>& t) const
     {
-        Matrix<Scalar> result = origins;
-        for (Eigen::Index i = 0u; i < t.size(); ++i)
-            result(axis_ids(i), i) += t(i);
-
+        Matrix<Scalar> result;
+        this->at(result, t);
         return result;
     }
 
+    void
+    at(Matrix<Scalar>& output_points,
+       const IndexVector& ray_indices,
+       const Vector<Scalar>& t) const
+    {
+        output_points = origins(Eigen::all, ray_indices);
+        for (const auto& i : ray_indices)
+            output_points(directions(i), i) += t(i);
+    }
+
     Matrix<Scalar> at(const IndexVector& ray_indices, const Vector<Scalar>& t) const
     {
-        Matrix<Scalar> result = origins(Eigen::all, ray_indices);
-        for (const auto& i : ray_indices)
-            result(axis_ids(i), i) += t(i);
-
+        Matrix<Scalar> result;
+        this->at(result, ray_indices, t);
         return result;
     }
 
+    void at(Vector<Scalar>& output_points, Index& ray_index, const Scalar t) const
+    {
+        output_points = origins(Eigen::all, ray_index);
+        output_points(directions(ray_index), ray_index) += t(ray_index);
+    }
+
     Vector<Scalar> at(Index& ray_index, const Scalar t) const
     {
         Vector<Scalar> result = origins(Eigen::all, ray_index);
-        result(axis_ids(ray_index), ray_index) += t(ray_index);
-
+        this->at(result, ray_index, t);
         return result;
     }
 };
