@@ -21,7 +21,7 @@ namespace samply {
 template <typename Scalar, typename Storage = AffineTransformStorage<Scalar>>
 class AffineDenseTransform
     : public AffineTransformBase<AffineDenseTransform<Scalar, Storage>, Storage> {
-public:
+  public:
     using Base = AffineTransformBase<AffineDenseTransform<Scalar, Storage>, Storage>;
     using Base::Base;
 
@@ -33,8 +33,8 @@ public:
      * @return Transform resulting from the concatenation.
      */
     template <typename OtherTransform, typename OtherStorage>
-    auto operator*(
-        const AffineTransformBase<OtherTransform, OtherStorage>& transform) const;
+    auto
+    operator*(const AffineTransformBase<OtherTransform, OtherStorage>& transform) const;
 
     /**
      * @brief Applies this affine transform to a matrix or vector.
@@ -43,7 +43,7 @@ public:
      * @return The transformed matrix.
      */
     template <typename MatrixType>
-    Matrix<Scalar> operator*(const Eigen::MatrixBase<MatrixType>& matrix) const;
+    auto operator*(const Eigen::MatrixBase<MatrixType>& matrix) const;
 
     /**
      * @brief Returns the inverse of this affine transform. If the inverse is
@@ -70,7 +70,7 @@ inline auto AffineDenseTransform<Scalar, Storage>::operator*(
 
 template <typename Scalar, typename Storage>
 template <typename MatrixType>
-inline Matrix<Scalar> AffineDenseTransform<Scalar, Storage>::operator*(
+inline auto AffineDenseTransform<Scalar, Storage>::operator*(
     const Eigen::MatrixBase<MatrixType>& matrix) const
 {
     return (Base::get_linear() * matrix).colwise() + Base::get_shift();
@@ -89,6 +89,6 @@ inline auto AffineDenseTransform<Scalar, Storage>::inverse() const
     return AffineDenseTransform<Scalar>(inv_T, -inv_T * Base::get_shift());
 }
 
-}  // namespace samply
+} // namespace samply
 
 #endif
\ No newline at end of file
