@@ -22,7 +22,7 @@ namespace samply {
 template <typename Scalar, typename Storage = AffineTransformStorage<Scalar>>
 class AffineDiagonalTransform
     : public AffineTransformBase<AffineDiagonalTransform<Scalar, Storage>, Storage> {
-public:
+  public:
     using Base = AffineTransformBase<AffineDiagonalTransform<Scalar, Storage>, Storage>;
     using Base::Base;
 
@@ -34,8 +34,8 @@ public:
      * @return Transform resulting from the concatenation.
      */
     template <typename OtherTransform, typename OtherStorage>
-    auto operator*(
-        const AffineTransformBase<OtherTransform, OtherStorage>& transform) const;
+    auto
+    operator*(const AffineTransformBase<OtherTransform, OtherStorage>& transform) const;
 
     /**
      * @brief Applies this affine transform to a matrix or vector.
@@ -44,7 +44,7 @@ public:
      * @return The transformed matrix.
      */
     template <typename MatrixType>
-    Matrix<Scalar> operator*(const Eigen::MatrixBase<MatrixType>& matrix) const;
+    auto operator*(const Eigen::MatrixBase<MatrixType>& matrix) const;
 
     /**
      * @brief Returns the inverse of this affine transform. If the inverse is
@@ -71,7 +71,7 @@ inline auto AffineDiagonalTransform<Scalar, Storage>::operator*(
 
 template <typename Scalar, typename Storage>
 template <typename MatrixType>
-inline Matrix<Scalar> AffineDiagonalTransform<Scalar, Storage>::operator*(
+inline auto AffineDiagonalTransform<Scalar, Storage>::operator*(
     const Eigen::MatrixBase<MatrixType>& matrix) const
 {
     return (Base::get_diagonal().asDiagonal() * matrix).colwise() + Base::get_shift();
@@ -86,6 +86,6 @@ inline auto AffineDiagonalTransform<Scalar, Storage>::inverse() const
     return AffineDiagonalTransform<Scalar>(inv_T, -inv_T * Base::get_shift());
 }
 
-}  // namespace samply
+} // namespace samply
 
 #endif
\ No newline at end of file
