@@ -16,6 +16,7 @@
 #include "affine_transform_base.h"
 #include "affine_transform_storage.h"
 #include "axis_rays_packet.h"
+#include "commons.h"
 #include "identity_transform.h"
 #include "linear_diagonal_transform.h"
 #include "linear_transform.h"
@@ -36,9 +37,9 @@ namespace samply {
 template <typename Scalar, typename Storage = AffineTransformStorage<Scalar>>
 class AffineTransform
     : public AffineTransformBase<AffineTransform<Scalar, Storage>, Storage> {
-public:
-    using AffineTransformBase<AffineTransform<Scalar, Storage>,
-                              Storage>::AffineTransformBase;
+  public:
+    using AffineTransformBase<AffineTransform<Scalar, Storage>, Storage>::
+        AffineTransformBase;
     using StorageRef = AffineTransformStorageConstRef<Scalar>;
 
     /**
@@ -64,8 +65,8 @@ public:
      * @return Reference to this instance.
      */
     template <typename OtherTransform, typename OtherStorage>
-    AffineTransform<Scalar>& operator=(
-        AffineTransformBase<OtherTransform, OtherStorage>&& other);
+    AffineTransform<Scalar>&
+    operator=(AffineTransformBase<OtherTransform, OtherStorage>&& other);
 
     /**
      * @brief Applies this affine transform after another transform. The
@@ -75,8 +76,12 @@ public:
      * @return Transform resulting from the concatenation.
      */
     template <typename OtherTransform, typename OtherStorage>
-    auto operator*(
-        const AffineTransformBase<OtherTransform, OtherStorage>& transform) const;
+    auto
+    operator*(const AffineTransformBase<OtherTransform, OtherStorage>& transform) const;
+
+    template <typename MatrixType>
+    void transform(
+        Matrix<Scalar>& output, const Eigen::MatrixBase<MatrixType>& matrix) const;
 
     /**
      * @brief Applies this affine transform to a matrix or vector.
@@ -87,6 +92,11 @@ public:
     template <typename MatrixType>
     Matrix<Scalar> operator*(const Eigen::MatrixBase<MatrixType>& matrix) const;
 
+    template <typename RaysStorage>
+    void transform(
+        RaysPacket<Scalar>& output_rays,
+        const RaysPacketBase<Scalar, RaysStorage>& rays) const;
+
     /**
      * @brief Apply this affine transform to a RaysPacket object.
      *
@@ -104,6 +114,8 @@ public:
      */
     RaysPacket<Scalar> operator*(const AxisRaysPacket<Scalar>& rays) const;
 
+    void transform(IndexVector& output, const IndexVector& axis) const;
+
     /**
      * @brief Apply this affine transform to a vector of axis. Note that this is only
      * valid if the transform is an identity transform.
@@ -111,7 +123,7 @@ public:
      * @param rays Axis to which the transform must be applied.
      * @return The transformed axis.
      */
-    IndexVector operator*(const Vector<Index>& axis) const;
+    const IndexVector& operator*(const IndexVector& axis) const;
 
     /**
      * @brief Returns a new affine transform containing only the linear part of
@@ -129,8 +141,7 @@ public:
      */
     auto inverse() const;
 
-    template <typename CastScalar>
-    AffineTransform<CastScalar> cast() const;
+    template <typename CastScalar> AffineTransform<CastScalar> cast() const;
 
     /**
      * @brief Checks whether this transform represents an identity transform.
@@ -148,9 +159,10 @@ public:
      */
     static AffineTransform<Scalar> identity(const Index n_dimensions);
 
-private:
+  private:
     // Types of affine transforms.
-    enum class TransformType_ {
+    enum class TransformType_
+    {
         AffineDiagonal,
         Dense,
         Identity,
@@ -203,7 +215,8 @@ inline void AffineTransform<Scalar, Storage>::reset_transform_type_()
             type_ = TransformType_::RowSelection;
         else
             type_ = TransformType_::Linear;
-    } else {
+    }
+    else {
         // Affine transform.
         if (this->get_linear().isZero())
             type_ = TransformType_::Reset;
@@ -294,8 +307,8 @@ inline const auto AffineTransform<Scalar, Storage>::asZero_() const noexcept
 //==============================================================================
 
 template <typename Scalar, typename Storage>
-inline AffineTransform<Scalar, Storage>::AffineTransform(const Matrix<Scalar>& T,
-                                                         const Vector<Scalar>& shift)
+inline AffineTransform<Scalar, Storage>::AffineTransform(
+    const Matrix<Scalar>& T, const Vector<Scalar>& shift)
     : AffineTransformBase<AffineTransform<Scalar>, AffineTransformStorage<Scalar>>(
           T, shift)
 {
@@ -335,37 +348,94 @@ inline auto AffineTransform<Scalar, Storage>::operator*(
 
 template <typename Scalar, typename Storage>
 template <typename MatrixType>
-inline Matrix<Scalar> AffineTransform<Scalar, Storage>::operator*(
-    const Eigen::MatrixBase<MatrixType>& matrix) const
+inline void AffineTransform<Scalar, Storage>::transform(
+    Matrix<Scalar>& output, const Eigen::MatrixBase<MatrixType>& matrix) const
 {
     switch (type_) {
     case TransformType_::AffineDiagonal:
-        return asAffineDiagonal_() * matrix;
+        output.noalias() = asAffineDiagonal_() * matrix;
         break;
     default:
     case TransformType_::Dense:
-        return asDense_() * matrix;
+        output.noalias() = asDense_() * matrix;
         break;
     case TransformType_::Identity:
-        return asIdentity_() * matrix;
+        output.noalias() = asIdentity_() * matrix;
         break;
     case TransformType_::Linear:
-        return asLinear_() * matrix;
+        output.noalias() = asLinear_() * matrix;
         break;
     case TransformType_::LinearDiagonal:
-        return asLinearDiagonal_() * matrix;
+        output.noalias() = asLinearDiagonal_() * matrix;
         break;
     case TransformType_::RowSelection:
-        return asRowSelection_() * matrix;
+        output.noalias() = asRowSelection_() * matrix;
         break;
     case TransformType_::Reset:
-        return asReset_() * matrix;
+        output.noalias() = asReset_() * matrix;
         break;
     case TransformType_::Translation:
-        return asTranslation_() * matrix;
+        output.noalias() = asTranslation_() * matrix;
         break;
     case TransformType_::Zero:
-        return asZero_() * matrix;
+        output.noalias() = asZero_() * matrix;
+        break;
+    }
+}
+
+template <typename Scalar, typename Storage>
+template <typename MatrixType>
+inline Matrix<Scalar> AffineTransform<Scalar, Storage>::operator*(
+    const Eigen::MatrixBase<MatrixType>& matrix) const
+{
+    Matrix<Scalar> output;
+    this->transform(output, matrix);
+    return output;
+}
+
+template <typename Scalar, typename Storage>
+template <typename RaysStorage>
+inline void AffineTransform<Scalar, Storage>::transform(
+    RaysPacket<Scalar>& output_rays,
+    const RaysPacketBase<Scalar, RaysStorage>& rays) const
+{
+    switch (type_) {
+    case TransformType_::AffineDiagonal:
+        output_rays.origins.noalias() = asAffineDiagonal_() * rays.origins;
+        output_rays.directions.noalias() = asLinearDiagonal_() * rays.directions;
+        break;
+    default:
+    case TransformType_::Dense:
+        output_rays.origins.noalias() = asDense_() * rays.origins;
+        output_rays.directions.noalias() = asLinear_() * rays.directions;
+        break;
+    case TransformType_::Identity:
+        output_rays.origins.noalias() = asIdentity_() * rays.origins;
+        output_rays.directions.noalias() = asIdentity_() * rays.directions;
+        break;
+    case TransformType_::Linear:
+        output_rays.origins.noalias() = asLinear_() * rays.origins;
+        output_rays.directions.noalias() = asLinear_() * rays.directions;
+        break;
+    case TransformType_::LinearDiagonal:
+        output_rays.origins.noalias() = asLinearDiagonal_() * rays.origins;
+        output_rays.directions.noalias() = asLinearDiagonal_() * rays.directions;
+        break;
+    case TransformType_::RowSelection:
+        output_rays.origins.noalias() = asRowSelection_() * rays.origins;
+        output_rays.directions.noalias() = asRowSelection_() * rays.directions;
+        break;
+    case TransformType_::Translation:
+        output_rays.origins.noalias() = asTranslation_() * rays.origins;
+        output_rays.directions.noalias() = rays.directions;
+        break;
+    case TransformType_::Reset:
+        output_rays.origins.noalias() = asReset_() * rays.origins;
+        output_rays.directions.noalias() = asZero_() * rays.directions;
+        break;
+    case TransformType_::Zero:
+        output_rays.origins.noalias() = asZero_() * rays.origins;
+        output_rays.directions.noalias() = asZero_() * rays.directions;
         break;
     }
 }
@@ -375,93 +445,78 @@ template <typename RaysStorage>
 inline RaysPacket<Scalar> AffineTransform<Scalar, Storage>::operator*(
     const RaysPacketBase<Scalar, RaysStorage>& rays) const
 {
-    switch (type_) {
-    case TransformType_::AffineDiagonal:
-        return RaysPacket<Scalar>{asAffineDiagonal_() * rays.origins,
-                                  asLinearDiagonal_() * rays.directions};
-        break;
-    default:
-    case TransformType_::Dense:
-        return RaysPacket<Scalar>{asDense_() * rays.origins,
-                                  asLinear_() * rays.directions};
-        break;
-    case TransformType_::Identity:
-        return RaysPacket<Scalar>{asIdentity_() * rays.origins,
-                                  asIdentity_() * rays.directions};
-        break;
-    case TransformType_::Linear:
-        return RaysPacket<Scalar>{asLinear_() * rays.origins,
-                                  asLinear_() * rays.directions};
-        break;
-    case TransformType_::LinearDiagonal:
-        return RaysPacket<Scalar>{asLinearDiagonal_() * rays.origins,
-                                  asLinearDiagonal_() * rays.directions};
-        break;
-    case TransformType_::RowSelection:
-        return RaysPacket<Scalar>{asRowSelection_() * rays.origins,
-                                  asRowSelection_() * rays.directions};
-        break;
-    case TransformType_::Translation:
-        return RaysPacket<Scalar>{asTranslation_() * rays.origins, rays.directions};
-        break;
-    case TransformType_::Reset:
-        return RaysPacket<Scalar>{asReset_() * rays.origins,
-                                  asZero_() * rays.directions};
-        break;
-    case TransformType_::Zero:
-        return RaysPacket<Scalar>{asZero_() * rays.origins,
-                                  asZero_() * rays.directions};
-        break;
-    }
+    RaysPacket<Scalar> result;
+    this->transform(result, rays);
+    return result;
 }
 
 template <typename Scalar, typename Storage>
-inline RaysPacket<Scalar> AffineTransform<Scalar, Storage>::operator*(
-    const AxisRaysPacket<Scalar>& rays) const
+inline RaysPacket<Scalar>
+AffineTransform<Scalar, Storage>::operator*(const AxisRaysPacket<Scalar>& rays) const
 {
     switch (type_) {
     case TransformType_::AffineDiagonal:
-        return RaysPacket<Scalar>{asAffineDiagonal_() * rays.origins,
-                                  this->get_linear()(Eigen::all, rays.axis_ids)};
+        return RaysPacket<Scalar>{
+            asAffineDiagonal_() * rays.origins,
+            this->get_linear()(Eigen::all, rays.directions)};
         break;
     default:
     case TransformType_::Dense:
-        return RaysPacket<Scalar>{asDense_() * rays.origins,
-                                  this->get_linear()(Eigen::all, rays.axis_ids)};
+        return RaysPacket<Scalar>{
+            asDense_() * rays.origins, this->get_linear()(Eigen::all, rays.directions)};
         break;
     case TransformType_::Identity:
-        return RaysPacket<Scalar>{asIdentity_() * rays.origins,
-                                  this->get_linear()(Eigen::all, rays.axis_ids)};
+        return RaysPacket<Scalar>{
+            asIdentity_() * rays.origins,
+            this->get_linear()(Eigen::all, rays.directions)};
         break;
     case TransformType_::Linear:
-        return RaysPacket<Scalar>{asLinear_() * rays.origins,
-                                  this->get_linear()(Eigen::all, rays.axis_ids)};
+        return RaysPacket<Scalar>{
+            asLinear_() * rays.origins,
+            this->get_linear()(Eigen::all, rays.directions)};
         break;
     case TransformType_::LinearDiagonal:
-        return RaysPacket<Scalar>{asLinearDiagonal_() * rays.origins,
-                                  this->get_linear()(Eigen::all, rays.axis_ids)};
+        return RaysPacket<Scalar>{
+            asLinearDiagonal_() * rays.origins,
+            this->get_linear()(Eigen::all, rays.directions)};
         break;
     case TransformType_::RowSelection:
         throw std::runtime_error("Not implemented yet");
         break;
     case TransformType_::Translation:
-        return RaysPacket<Scalar>{asTranslation_() * rays.origins,
-                                  this->get_linear()(Eigen::all, rays.axis_ids)};
+        return RaysPacket<Scalar>{
+            asTranslation_() * rays.origins,
+            this->get_linear()(Eigen::all, rays.directions)};
         break;
     case TransformType_::Reset:
-        return RaysPacket<Scalar>{asReset_() * rays.origins,
-                                  this->get_linear()(Eigen::all, rays.axis_ids)};
+        return RaysPacket<Scalar>{
+            asReset_() * rays.origins, this->get_linear()(Eigen::all, rays.directions)};
         break;
     case TransformType_::Zero:
-        return RaysPacket<Scalar>{asZero_() * rays.origins,
-                                  this->get_linear()(Eigen::all, rays.axis_ids)};
+        return RaysPacket<Scalar>{
+            asZero_() * rays.origins, this->get_linear()(Eigen::all, rays.directions)};
         break;
     }
 }
 
 template <typename Scalar, typename Storage>
-inline IndexVector AffineTransform<Scalar, Storage>::operator*(
-    const IndexVector& axis) const
+inline void AffineTransform<Scalar, Storage>::transform(
+    IndexVector& output, const IndexVector& axis) const
+{
+    switch (type_) {
+    case TransformType_::Identity:
+        output = axis;
+        break;
+    default:
+        throw std::runtime_error(
+            "Axis vectors can only be transformed with an identity transform");
+        break;
+    }
+}
+
+template <typename Scalar, typename Storage>
+inline const IndexVector&
+AffineTransform<Scalar, Storage>::operator*(const IndexVector& axis) const
 {
     switch (type_) {
     case TransformType_::Identity:
@@ -488,7 +543,8 @@ inline auto AffineTransform<Scalar, Storage>::inverse() const
     Matrix<Scalar> inv_T;
     if (this->storage_.get_linear().rows() == this->storage_.get_linear().cols()) {
         inv_T = this->storage_.get_linear().inverse();
-    } else {
+    }
+    else {
         inv_T = this->storage_.get_linear()
                     .completeOrthogonalDecomposition()
                     .pseudoInverse();
@@ -516,13 +572,14 @@ inline bool AffineTransform<Scalar, Storage>::is_identity() const
 //==============================================================================
 
 template <typename Scalar, typename Storage>
-inline AffineTransform<Scalar> AffineTransform<Scalar, Storage>::identity(
-    const Index n_dimensions)
+inline AffineTransform<Scalar>
+AffineTransform<Scalar, Storage>::identity(const Index n_dimensions)
 {
-    return AffineTransform<Scalar>(Matrix<Scalar>::Identity(n_dimensions, n_dimensions),
-                                   Vector<Scalar>::Zero(n_dimensions));
+    return AffineTransform<Scalar>(
+        Matrix<Scalar>::Identity(n_dimensions, n_dimensions),
+        Vector<Scalar>::Zero(n_dimensions));
 }
 
-}  // namespace samply
+} // namespace samply
 
 #endif
