@@ -20,7 +20,7 @@ namespace samply {
 template <typename Scalar, typename Storage = AffineTransformStorage<Scalar>>
 class IdentityTransform
     : public AffineTransformBase<IdentityTransform<Scalar, Storage>, Storage> {
-public:
+  public:
     using Base = AffineTransformBase<IdentityTransform<Scalar, Storage>, Storage>;
     using Base::Base;
 
@@ -39,8 +39,8 @@ public:
      * @return Transform resulting from the concatenation.
      */
     template <typename OtherTransform, typename OtherStorage>
-    auto operator*(
-        const AffineTransformBase<OtherTransform, OtherStorage>& transform) const;
+    auto
+    operator*(const AffineTransformBase<OtherTransform, OtherStorage>& transform) const;
 
     /**
      * @brief Applies this affine transform to a matrix or vector.
@@ -49,7 +49,8 @@ public:
      * @return The transformed matrix.
      */
     template <typename MatrixType>
-    Matrix<Scalar> operator*(const Eigen::MatrixBase<MatrixType>& matrix) const;
+    const Eigen::MatrixBase<MatrixType>&
+    operator*(const Eigen::MatrixBase<MatrixType>& matrix) const;
 
     /**
      * @brief Returns the inverse of this affine transform. If the inverse is
@@ -70,8 +71,7 @@ inline IdentityTransform<Scalar, Storage>::IdentityTransform(
     : AffineTransformBase<IdentityTransform, Storage>(
           Eigen::MatrixXd::Identity(n_dimensions, n_dimensions),
           Eigen::VectorXd::Zero(n_dimensions))
-{
-}
+{}
 
 template <typename Scalar, typename Storage>
 template <typename OtherTransform, typename OtherStorage>
@@ -83,20 +83,11 @@ inline auto IdentityTransform<Scalar, Storage>::operator*(
 
 template <typename Scalar, typename Storage>
 template <typename MatrixType>
-inline Matrix<Scalar> IdentityTransform<Scalar, Storage>::operator*(
+inline const Eigen::MatrixBase<MatrixType>&
+IdentityTransform<Scalar, Storage>::operator*(
     const Eigen::MatrixBase<MatrixType>& matrix) const
 {
-    if (Base::get_linear().rows() == Base::get_linear().cols()) {
-        return matrix;
-    } else {
-        Matrix<Scalar> result =
-            Matrix<Scalar>::Zero(Base::get_linear().rows(), matrix.cols());
-        result.block(0, 0, std::min(result.rows(), matrix.rows()),
-                     std::min(result.cols(), matrix.cols())) =
-            matrix.block(0, 0, std::min(result.rows(), matrix.rows()),
-                         std::min(result.cols(), matrix.cols()));
-        return result;
-    }
+    return matrix;
 }
 
 template <typename Scalar, typename Storage>
@@ -105,6 +96,6 @@ inline auto IdentityTransform<Scalar, Storage>::inverse() const
     return IdentityTransform(Base::get_shift().size());
 }
 
-}  // namespace samply
+} // namespace samply
 
 #endif
\ No newline at end of file
