@@ -20,7 +20,7 @@ namespace samply {
 template <typename Scalar, typename Storage = AffineTransformStorage<Scalar>>
 class LinearDiagonalTransform
     : public AffineTransformBase<LinearDiagonalTransform<Scalar, Storage>, Storage> {
-public:
+  public:
     using Base = AffineTransformBase<LinearDiagonalTransform<Scalar, Storage>, Storage>;
     using Base::Base;
 
@@ -32,8 +32,8 @@ public:
      * @return Transform resulting from the concatenation.
      */
     template <typename OtherTransform, typename OtherStorage>
-    auto operator*(
-        const AffineTransformBase<OtherTransform, OtherStorage>& transform) const;
+    auto
+    operator*(const AffineTransformBase<OtherTransform, OtherStorage>& transform) const;
 
     /**
      * @brief Applies this affine transform to a matrix or vector.
@@ -42,7 +42,7 @@ public:
      * @return The transformed matrix.
      */
     template <typename MatrixType>
-    Matrix<Scalar> operator*(const Eigen::MatrixBase<MatrixType>& matrix) const;
+    auto operator*(const Eigen::MatrixBase<MatrixType>& matrix) const;
 
     /**
      * @brief Returns the inverse of this affine transform. If the inverse is
@@ -69,7 +69,7 @@ inline auto LinearDiagonalTransform<Scalar, Storage>::operator*(
 
 template <typename Scalar, typename Storage>
 template <typename MatrixType>
-inline Matrix<Scalar> LinearDiagonalTransform<Scalar, Storage>::operator*(
+inline auto LinearDiagonalTransform<Scalar, Storage>::operator*(
     const Eigen::MatrixBase<MatrixType>& matrix) const
 {
     return Base::get_diagonal().asDiagonal() * matrix;
@@ -84,6 +84,6 @@ inline auto LinearDiagonalTransform<Scalar, Storage>::inverse() const
     return LinearDiagonalTransform<Scalar>(inv_T, Vector<Scalar>::Zero(inv_T.rows()));
 }
 
-}  // namespace samply
+} // namespace samply
 
 #endif
\ No newline at end of file
