@@ -4,10 +4,9 @@
 import logging
 from typing import List, Optional, Union
 
+import cobra
 import numpy as np
 import pandas as pd
-
-import cobra
 from cobra.flux_analysis.variability import flux_variability_analysis
 
 from .constants import (
@@ -308,6 +307,21 @@ class QuantitativeAssessment:
             }
         )
 
+        # Verify whether the shadow prices were computed correctly.
+        if (
+            orthant_pmo.sign_constraints[0].dual_value is None
+            or orthant_pmo.sign_constraints[1].dual_value is None
+        ):
+            logger.warning(
+                "Unable to compute shadow prices. Solve again with verbose=True to see the solver output."
+            )
+            sp_drg = np.zeros(len(pmo_problem.T.reaction_ids)) * np.nan
+        else:
+            sp_drg = np.maximum(
+                orthant_pmo.sign_constraints[0].dual_value,
+                orthant_pmo.sign_constraints[1].dual_value,
+            ).ravel()
+
         self._reactions_df = pd.DataFrame(
             {
                 "id": pmo_problem.T.reaction_ids,
@@ -320,10 +334,7 @@ class QuantitativeAssessment:
                 else np.nan,
                 "z_drg": self._make_z_scores(pmo_problem, "drg"),
                 "z_drg0": self._make_z_scores(pmo_problem, "drg0"),
-                "sp_drg": np.maximum(
-                    orthant_pmo.sign_constraints[0].dual_value,
-                    orthant_pmo.sign_constraints[1].dual_value,
-                ).ravel(),
+                "sp_drg": sp_drg,
             }
         )
 
@@ -520,7 +531,11 @@ def prepare_for_pta(
         True if the method should restrict the flux bounds with FVA, false otherwise. By
         default True.
     """
+
     logger.info("Preparing model for PTA ...")
+    result = model.optimize()
+    assert result.status != "infeasible", "Model is infeasible."
+
     # Run structural assessment and auto-resolve all inconsistencies.
     if autoresolve_inconsistencies:
         assessment = StructuralAssessment(model, biomass_id, atpm_id)
