@@ -132,7 +132,9 @@ class PmoProblem:
 
     _REFERENCE_COEFFICIENT = 1e2
     _MAX_COEFFICIENT_RANGE = 5e8
-    _DEFAULT_SOLVER_OPTIONS = {cp.GUROBI: {"IntFeasTol": 1e-9, "FeasibilityTol": 1e-9}}
+    _DEFAULT_SOLVER_OPTIONS = {
+        cp.GUROBI: {"IntFeasTol": 1e-9, "FeasibilityTol": 1e-9, "BarQCPConvTol": 1e-8}
+    }
 
     def __init__(
         self,
