@@ -9,13 +9,15 @@ import random
 import tempfile
 from typing import List, Optional, Tuple, Union
 
+import numpy as np
+import pandas as pd
+import scipy as sp
+from scipy.stats.distributions import chi2
+
 import _pta_python_binaries as pb
 import cobra
 import cvxpy as cp
-import numpy as np
-import pandas as pd
 from pta.sampling.convergence_manager import ConvergenceManager
-from scipy.stats.distributions import chi2
 
 from ..constants import (
     default_max_psrf,
@@ -481,7 +483,7 @@ def sample_drg(
     assert model.B.to_drg_transform is not None
     assert num_samples > 0
     assert num_direction_samples > 0
-    max_steps = max_steps if max_steps >= 1 else 2 ** 63
+    max_steps = max_steps if max_steps >= 1 else 2**63
     assert max_psrf > 1.0
     if num_chains < 0:
         if initial_points is not None:
@@ -491,7 +493,7 @@ def sample_drg(
     num_initial_steps = (
         num_initial_steps
         if num_initial_steps > 0
-        else model.B.dimensionality ** 2 + num_samples
+        else model.B.dimensionality**2 + num_samples
     )
     assert feasibility_cache_size >= 0
     assert min_rel_region_length > 0
@@ -836,7 +838,7 @@ def _sample_conditional_mvn(
     A = a @ a.T
     B = a @ b.T
     C = b @ b.T
-    C_inv = np.linalg.pinv(C, hermitian=True)
+    C_inv = sp.linalg.pinvh(C)
 
     E_X = mean[X_ids]
     E_Y = mean[Y_ids]
