@@ -4,19 +4,17 @@
 import logging
 from typing import Dict, List, Optional, Tuple, Union
 
+import cobra.core
 import numpy as np
 import numpy.linalg as la
 import scipy.linalg
-from component_contribution.linalg import LINALG
-from equilibrator_cache import CompoundCache, create_compound_cache_from_zenodo
-
-import cobra.core
 from cobra.util.array import create_stoichiometric_matrix
+from component_contribution.linalg import LINALG
+from equilibrator_cache import create_compound_cache_from_zenodo
 
 from .compartment_parameters import CompartmentParameters
 from .concentrations_prior import ConcentrationsPrior
 from .constants import Q, R, default_min_eigenvalue_tds_basis
-from .distributions import NormalDistribution
 from .flux_space import FluxSpace
 from .gibbs_estimators import EquilibratorGibbsEstimator, GibbsEstimatorInterface
 from .metabolite import Metabolite
@@ -41,7 +39,7 @@ class ThermodynamicSpace:
 
     Parameters
     ----------
-    S_constraints : np.array
+    S_constraints : np.ndarray
         Stoichiometric matrix of the reactions covered by thermodynamic constraints.
     reaction_ids : List[str]
         Identifiers of the reactions covered by thermodynamic constraints.
@@ -61,7 +59,7 @@ class ThermodynamicSpace:
 
     def __init__(
         self,
-        S_constraints: np.array,
+        S_constraints: np.ndarray,
         reaction_ids: List[str],
         metabolites: List[Metabolite],
         metabolite_ids: List[str] = None,
@@ -176,7 +174,7 @@ class ThermodynamicSpace:
         return self._metabolites
 
     @property
-    def S_constraints(self) -> np.array:
+    def S_constraints(self) -> np.ndarray:
         """Gets stoichiometric matrix of the reactions with thermodynamic
         constraints."""
         return self._S_constraints
@@ -250,13 +248,24 @@ class ThermodynamicSpace:
         # Parse metabolites from the model.
         metabolites = []
         metabolite_ids = []
+        num_missing_charges = 0
         for i, m in enumerate(model.metabolites):
             if is_metabolite_needed[i]:
+                if m.charge is None:
+                    num_missing_charges += 1
                 metabolite = metabolite_interpreter.read(m.id)
                 metabolite.nH = m.elements.get("H", 0)
-                metabolite.z = m.charge
+                metabolite.z = m.charge or 0
                 metabolites.append(metabolite)
                 metabolite_ids.append(m.id)
+        if num_missing_charges > 0:
+            logger.warning(
+                f"{num_missing_charges} metabolites have unspecified charge in the "
+                "model. PTA will assume a charge of zero for these metabolites, but "
+                "this may lead to unbalanced reactions and inconsistencies. It is "
+                "recommended to use a model with fully specified chemical formulas and "
+                "charges."
+            )
 
         return ThermodynamicSpace(
             S_constraints,
@@ -324,9 +333,9 @@ class ThermodynamicSpaceBasis:
         explicit_drg: bool = True,
         min_eigenvalue: float = default_min_eigenvalue_tds_basis,
     ):
-        self._to_log_conc_transform: Optional[Tuple[np.array, np.array]] = None
-        self._to_drg0_transform: Optional[Tuple[np.array, np.array]] = None
-        self._to_drg_transform: Optional[Tuple[np.array, np.array]] = None
+        self._to_log_conc_transform: Optional[Tuple[np.ndarray, np.ndarray]] = None
+        self._to_drg0_transform: Optional[Tuple[np.ndarray, np.ndarray]] = None
+        self._to_drg_transform: Optional[Tuple[np.ndarray, np.ndarray]] = None
 
         self._observables_ranges: Dict[str, List[int]] = {
             "drg": [],
@@ -343,25 +352,25 @@ class ThermodynamicSpaceBasis:
         )
 
     @property
-    def to_log_conc_transform(self) -> Optional[Tuple[np.array, np.array]]:
+    def to_log_conc_transform(self) -> Optional[Tuple[np.ndarray, np.ndarray]]:
         """Gets the transformation from this space to log-concentrations. :code:`None`
         if concentrations are not represented explicitely."""
         return self._to_log_conc_transform
 
     @property
-    def to_drg0_transform(self) -> Optional[Tuple[np.array, np.array]]:
+    def to_drg0_transform(self) -> Optional[Tuple[np.ndarray, np.ndarray]]:
         """Gets the transformation from this space to DrG'°. :code:`None`
         if standard reaction energies are not represented explicitely."""
         return self._to_drg0_transform
 
     @property
-    def to_drg_transform(self) -> Optional[Tuple[np.array, np.array]]:
+    def to_drg_transform(self) -> Optional[Tuple[np.ndarray, np.ndarray]]:
         """Gets the transformation from this space to DrG'. :code:`None`
         if reaction energies are not represented explicitely."""
         return self._to_drg_transform
 
     @property
-    def to_observables_transform(self) -> Tuple[np.array, np.array]:
+    def to_observables_transform(self) -> Tuple[np.ndarray, np.ndarray]:
         """Gets the transformation from this space to the selected observables."""
         return self._to_observables_transform
 
@@ -371,7 +380,7 @@ class ThermodynamicSpaceBasis:
         return self._observables_ranges
 
     @property
-    def sigmas(self) -> np.array:
+    def sigmas(self) -> np.ndarray:
         """Gets a vector containing the standard deviation of each variable in
         the minimal basis."""
         return self._sigmas
@@ -381,65 +390,65 @@ class ThermodynamicSpaceBasis:
         """Gets the dimensionality of the basis."""
         return self._dimensionality
 
-    def to_log_conc(self, vars: np.array) -> np.array:
+    def to_log_conc(self, basis_vars: np.ndarray) -> np.ndarray:
         """Transform a vector or matrix in the basis to a vector or matrix of
         log-concentrations.
 
         Parameters
         ----------
-        vars : np.array
+        basis_vars : np.ndarray
             The input vector or matrix.
 
         Returns
         -------
-        np.array
+        np.ndarray
             The transformed vector or matrix. :code:`None` if concentrations are not
             represented explicitely.
         """
         if not self.to_log_conc_transform:
             return None
         else:
-            return apply_transform(vars, self.to_log_conc_transform)
+            return apply_transform(basis_vars, self.to_log_conc_transform)
 
-    def to_drg0(self, vars: np.array) -> np.array:
+    def to_drg0(self, basis_vars: np.ndarray) -> np.ndarray:
         """Transform a vector or matrix in the basis to a vector or matrix of
         standard reaction energies.
 
         Parameters
         ----------
-        vars : np.array
+        basis_vars : np.ndarray
             The input vector or matrix.
 
         Returns
         -------
-        np.array
+        np.ndarray
             The transformed vector or matrix. :code:`None` if standard reaction energies
             are not represented explicitely.
         """
         if not self.to_drg0_transform:
             return None
         else:
-            return apply_transform(vars, self.to_drg0_transform)
+            return apply_transform(basis_vars, self.to_drg0_transform)
 
-    def to_drg(self, vars: np.array) -> np.array:
+    def to_drg(self, basis_vars: np.ndarray) -> np.ndarray:
         """Transform a vector or matrix in the basis to a vector or matrix of
         reaction energies.
 
         Parameters
         ----------
-        vars : np.array
+        basis_vars : np.ndarray
             The input vector or matrix.
 
         Returns
         -------
-        np.array
+        np.ndarray
             The transformed vector or matrix. :code:`None` if reaction energies are not
             represented explicitely.
         """
         if not self.to_drg_transform:
             return None
         else:
-            return apply_transform(vars, self.to_drg_transform)
+            return apply_transform(basis_vars, self.to_drg_transform)
 
     def _compute_basis(
         self,
